% rebase('base.html')

<h1>Welcome to the exam proctoring system!</h1>
<h2>Privacy notice</h2>
<p>
	Welcome to the exam proctoring system! This program will collect the following information during your exam:
</p>
<ul>
	<li>A video, recorded by your webcam</li>
	<li>A screencast, i.e. the content of all of your monitors</li>
	<li>Your processes, i.e. the programs that are running on your PC</li>
</ul>
<p>
	Before continuing, you are advised to:
</p>
<ol>
	<li>Close any program you are not allowed to run during your exam</li>
	<li>Remove any sensible information from your desktop (such as files, folders, wallpapers you would not like to show)</li>
	<li>Disable desktop notifications</li>
</ol>
<p>
	All the collected information will be sent to the Commission in charge of your exam, and will be examined in order to assest the validity of your exam.
</p>
<p>
	<a class='btn btn-primary' href='/start'>I agree</a> <a class='btn btn-warning' href='/exit?back=privacy'>Exit</a>
</p>
